@@ -2,11 +2,12 @@
 
 mod cell;
 pub mod condition;
+pub mod mpsc;
 pub mod oneshot;
 pub mod pool;
 
-/// Error returned from a [`Receiver`](Receiver) when the corresponding
-/// [`Sender`](Sender) is dropped.
+/// Error returned from a `Receiver` when the corresponding
+/// `Sender` is dropped.
 #[derive(Clone, Copy, PartialEq, Eq, Debug)]
 pub struct Canceled;
 
